/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_XLdJbJq6);
  numBytes += sLine_init(&sLine_FB13jTQf);
  numBytes += sLine_init(&sLine_x6vYuA93);
  numBytes += sLine_init(&sLine_ZS3MVA2n);
  numBytes += sLine_init(&sLine_z83uZGVH);
  numBytes += sBiquad_init(&sBiquad_s_FsIvn6xM);
  numBytes += sLine_init(&sLine_W2KQonv4);
  numBytes += sLine_init(&sLine_t4oBMgmz);
  numBytes += sLine_init(&sLine_gNOLj3oU);
  numBytes += sLine_init(&sLine_iQZSyOuE);
  numBytes += sBiquad_init(&sBiquad_s_BEvKqZFE);
  numBytes += sLine_init(&sLine_jdhDHsGm);
  numBytes += sLine_init(&sLine_avsmylyo);
  numBytes += sLine_init(&sLine_QPHzUIM0);
  numBytes += sLine_init(&sLine_3jAYHYcw);
  numBytes += sLine_init(&sLine_3X6jcika);
  numBytes += sBiquad_init(&sBiquad_s_HhgoH7n5);
  numBytes += sLine_init(&sLine_RU5HxvtD);
  numBytes += sLine_init(&sLine_epRe6M1g);
  numBytes += sLine_init(&sLine_ku9hKyVk);
  numBytes += sLine_init(&sLine_Krauvyn8);
  numBytes += sLine_init(&sLine_L7ubCZ9f);
  numBytes += sBiquad_init(&sBiquad_s_r16WKEZr);
  numBytes += sLine_init(&sLine_KlqGuDxv);
  numBytes += sLine_init(&sLine_WH9VXLdd);
  numBytes += sLine_init(&sLine_p37h2B2U);
  numBytes += sLine_init(&sLine_GgjSUe53);
  numBytes += sBiquad_init(&sBiquad_s_bOO2If94);
  numBytes += sLine_init(&sLine_yPfTn93o);
  numBytes += sLine_init(&sLine_LP2II8li);
  numBytes += sLine_init(&sLine_Dsif3AWG);
  numBytes += sLine_init(&sLine_5PnBOGPw);
  numBytes += sLine_init(&sLine_SEltjmPJ);
  numBytes += sBiquad_init(&sBiquad_s_Mh0Kibmy);
  numBytes += sLine_init(&sLine_FLVS4wT6);
  numBytes += sPhasor_k_init(&sPhasor_yNFmI11y, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_hDjhdwA0);
  numBytes += sRPole_init(&sRPole_OoI6H05W);
  numBytes += sRPole_init(&sRPole_iJYBvFZB);
  numBytes += sTabhead_init(&sTabhead_YbPb05yc, &hTable_hbN5hlr9);
  numBytes += sTabread_init(&sTabread_o1mcaQfo, &hTable_hbN5hlr9, false);
  numBytes += sTabread_init(&sTabread_DsDmYT9s, &hTable_hbN5hlr9, false);
  numBytes += sLine_init(&sLine_GRA5D9rs);
  numBytes += sTabhead_init(&sTabhead_jiwDJ6gz, &hTable_ecm7aEce);
  numBytes += sTabread_init(&sTabread_FHUaXP6F, &hTable_ecm7aEce, false);
  numBytes += sTabread_init(&sTabread_DDAlTIcC, &hTable_ecm7aEce, false);
  numBytes += sLine_init(&sLine_8AuUDiTO);
  numBytes += sTabwrite_init(&sTabwrite_1CQQ9hQW, &hTable_ecm7aEce);
  numBytes += sTabwrite_init(&sTabwrite_d1UnsjEj, &hTable_hbN5hlr9);
  numBytes += sLine_init(&sLine_0CLbxp3F);
  numBytes += sPhasor_k_init(&sPhasor_ZnIrTMyZ, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_LNmnrb2u);
  numBytes += sRPole_init(&sRPole_W9NLTj5n);
  numBytes += sRPole_init(&sRPole_ZV3sIsj7);
  numBytes += sTabhead_init(&sTabhead_IdFu6vGX, &hTable_wI3XSRy2);
  numBytes += sTabread_init(&sTabread_EefyVeF7, &hTable_wI3XSRy2, false);
  numBytes += sTabread_init(&sTabread_DdMDIDWv, &hTable_wI3XSRy2, false);
  numBytes += sLine_init(&sLine_kWhSGRWf);
  numBytes += sTabhead_init(&sTabhead_mPPRRI2Q, &hTable_cqHivfi4);
  numBytes += sTabread_init(&sTabread_Cri4WlIp, &hTable_cqHivfi4, false);
  numBytes += sTabread_init(&sTabread_GmY7G2P8, &hTable_cqHivfi4, false);
  numBytes += sLine_init(&sLine_t6xQ8OhI);
  numBytes += sTabwrite_init(&sTabwrite_rGs4DYf0, &hTable_cqHivfi4);
  numBytes += sTabwrite_init(&sTabwrite_a2uhEWMx, &hTable_wI3XSRy2);
  numBytes += sLine_init(&sLine_MjTQtPtN);
  numBytes += sPhasor_k_init(&sPhasor_ikm8GvEK, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_gsjbwBhE);
  numBytes += sRPole_init(&sRPole_btVZsamO);
  numBytes += sRPole_init(&sRPole_8vDgbBrS);
  numBytes += sTabhead_init(&sTabhead_ZVrT6OBS, &hTable_C6pUYsQg);
  numBytes += sTabread_init(&sTabread_eXfy0Gj5, &hTable_C6pUYsQg, false);
  numBytes += sTabread_init(&sTabread_4qL0FFAY, &hTable_C6pUYsQg, false);
  numBytes += sLine_init(&sLine_CF2E3EVA);
  numBytes += sTabhead_init(&sTabhead_CFLKa9XF, &hTable_73gc2tIx);
  numBytes += sTabread_init(&sTabread_GQs7hpBx, &hTable_73gc2tIx, false);
  numBytes += sTabread_init(&sTabread_WwRaf1ci, &hTable_73gc2tIx, false);
  numBytes += sLine_init(&sLine_CgKIF7uL);
  numBytes += sTabwrite_init(&sTabwrite_TIIRkByq, &hTable_73gc2tIx);
  numBytes += sTabwrite_init(&sTabwrite_Q4R20UFV, &hTable_C6pUYsQg);
  numBytes += cVar_init_f(&cVar_ZovOz8sO, 0.0f);
  numBytes += cVar_init_f(&cVar_NSAvrq6e, 0.0f);
  numBytes += cVar_init_f(&cVar_9yGnwHVx, 0.0f);
  numBytes += cVar_init_f(&cVar_zBRiBy6C, 0.0f);
  numBytes += cSlice_init(&cSlice_KQCDip2q, 1, -1);
  numBytes += cVar_init_f(&cVar_1YBpiBPh, 1337.0f);
  numBytes += cVar_init_f(&cVar_fCMdw0oC, 0.0f);
  numBytes += cIf_init(&cIf_qmtU2KBO, false);
  numBytes += cIf_init(&cIf_wa5xe6pU, false);
  numBytes += cBinop_init(&cBinop_ZHcjxyr8, 0.0f); // __pow
  numBytes += cIf_init(&cIf_GnRbp62d, false);
  numBytes += cBinop_init(&cBinop_4JbDopnl, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_TlJJ9mt1, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_9Ikp5TE1, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_e5hbszRZ, 0.0f);
  numBytes += cIf_init(&cIf_XbrJ7GyY, false);
  numBytes += cIf_init(&cIf_G3BfaUlU, false);
  numBytes += cBinop_init(&cBinop_zj0nuU3F, 0.0f); // __pow
  numBytes += cIf_init(&cIf_n9OmH3kA, false);
  numBytes += cBinop_init(&cBinop_6eH18ccO, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_eHF6CkeW, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_6rkp971H, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_NIUfiMLd, 0.0f);
  numBytes += cIf_init(&cIf_fYp92otv, false);
  numBytes += cIf_init(&cIf_Ac0sGMDS, false);
  numBytes += cBinop_init(&cBinop_LZkao9Gw, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ZEaOUn9v, false);
  numBytes += cBinop_init(&cBinop_mBd8Fil1, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_DKmbz1Dv, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_1Y2X9tK4, -15.0f); // __eq
  numBytes += cIf_init(&cIf_weFNTngO, false);
  numBytes += cSlice_init(&cSlice_H0lacEeE, 1, -1);
  numBytes += cVar_init_f(&cVar_HwyRZcoy, 0.0f);
  numBytes += cSlice_init(&cSlice_7qveQi4z, 1, -1);
  numBytes += cVar_init_f(&cVar_bXKOWz8u, 0.0f);
  numBytes += cSlice_init(&cSlice_47gzll3K, 1, -1);
  numBytes += cVar_init_f(&cVar_xdg9NDo5, 0.0f);
  numBytes += cSlice_init(&cSlice_EDEgvUEH, 1, -1);
  numBytes += cVar_init_f(&cVar_vw1PIAs3, 0.313f);
  numBytes += cBinop_init(&cBinop_BOXWj8eT, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_pxXtjheA, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_CKf2NfaQ, 0.0f);
  numBytes += cVar_init_f(&cVar_fX2wzFe3, 1337.0f);
  numBytes += cVar_init_f(&cVar_TbUO62Uu, 0.3f);
  numBytes += cBinop_init(&cBinop_eINqciv1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4hcYfGNP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ne2gr5Xr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UyFl6PWf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vGR84zkK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Nb9TMWyh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_swU5slsg, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_hcnFlZLD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_nLIP089Z, 0.0f);
  numBytes += cVar_init_f(&cVar_AAyuPqol, 1337.0f);
  numBytes += cVar_init_f(&cVar_deU8rx9M, 0.313f);
  numBytes += cBinop_init(&cBinop_ZuVDMuPN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8Us4gGU7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_r1N5Fw3O, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4O2fZtjj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XBZwHVyQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vdsJAA3N, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Od8QpTBS, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_WSYoG2th, 0.0f);
  numBytes += cVar_init_f(&cVar_9B2nbh3N, 1037.0f);
  numBytes += cVar_init_f(&cVar_8K8KnprX, 0.4f);
  numBytes += cBinop_init(&cBinop_dEdxLiK6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4CrtcssM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3FqfOnFR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_obxYA3hz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RqQLuqyG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xcnNDK7e, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_bJVmHlgL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jQqz1FoQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_z2X0AFSh, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_fkb8CLcr, 1, -1);
  numBytes += cVar_init_f(&cVar_XRFS5uzn, 1337.0f);
  numBytes += cVar_init_f(&cVar_vYbOPsDL, 0.0f);
  numBytes += cIf_init(&cIf_93BPAayp, false);
  numBytes += cIf_init(&cIf_SgMvNx8O, false);
  numBytes += cBinop_init(&cBinop_FJVVoUDL, 0.0f); // __pow
  numBytes += cIf_init(&cIf_gF5KVfuu, false);
  numBytes += cBinop_init(&cBinop_8sTtfl3i, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_klmVxww7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_0yqvKP3z, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_IiWsqxSy, 0.0f);
  numBytes += cIf_init(&cIf_HJPrHqGt, false);
  numBytes += cIf_init(&cIf_nuDmCNFf, false);
  numBytes += cBinop_init(&cBinop_Wz6uvkCa, 0.0f); // __pow
  numBytes += cIf_init(&cIf_c27ct0Tg, false);
  numBytes += cBinop_init(&cBinop_yre5JBsn, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_cBwN9uZo, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_F1SVR8vh, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_IcbZFiAf, 0.0f);
  numBytes += cIf_init(&cIf_8KyDtSzE, false);
  numBytes += cIf_init(&cIf_Z7L6oIY4, false);
  numBytes += cBinop_init(&cBinop_9I4dPuBe, 0.0f); // __pow
  numBytes += cIf_init(&cIf_WgES5CZe, false);
  numBytes += cBinop_init(&cBinop_MkO0ckzb, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_p2GAE1zy, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_uNflJNa7, -15.0f); // __eq
  numBytes += cIf_init(&cIf_oBl6AapX, false);
  numBytes += cSlice_init(&cSlice_fdI14mGp, 1, -1);
  numBytes += cVar_init_f(&cVar_vN1n7vP3, 0.0f);
  numBytes += cSlice_init(&cSlice_2hNfK1nE, 1, -1);
  numBytes += cVar_init_f(&cVar_04Bgmd2S, 0.0f);
  numBytes += cSlice_init(&cSlice_Ephck8wl, 1, -1);
  numBytes += cVar_init_f(&cVar_doPLeQVQ, 0.0f);
  numBytes += cSlice_init(&cSlice_SiMlMIXi, 1, -1);
  numBytes += cVar_init_f(&cVar_NyhFtEfy, 0.313f);
  numBytes += cBinop_init(&cBinop_CCXhJgzV, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ih4PpUJG, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_KYUqNqvp, 0.0f);
  numBytes += cVar_init_f(&cVar_Nf8CrU7B, 1337.0f);
  numBytes += cVar_init_f(&cVar_kaMk0Kw6, 0.3f);
  numBytes += cBinop_init(&cBinop_beZJgt7B, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_heFp9rxe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_L7OiNMFB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pAJTfjT0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_z3jdo7He, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7dORlf1w, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XRkoNLdA, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_kMkQMPHb, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_q6KCu910, 0.0f);
  numBytes += cVar_init_f(&cVar_EtsbaGhU, 1337.0f);
  numBytes += cVar_init_f(&cVar_JZbew8m9, 0.313f);
  numBytes += cBinop_init(&cBinop_3etkvjpq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_afSFSWoJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_I5CeLgT4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_L0igb0pG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ghCtk7lM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UUYqntEq, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_V7RSxp0b, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_TzeaOnfo, 0.0f);
  numBytes += cVar_init_f(&cVar_0N608zZH, 1037.0f);
  numBytes += cVar_init_f(&cVar_jc3PPlYf, 0.4f);
  numBytes += cBinop_init(&cBinop_7903jqqL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pJyouG42, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MrN4e4d4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5POI1bQi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_p2C0SpsH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nItNXOrT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_lrWlTZAZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wOo0RVca, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CjjxqviT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_oJgqxgDq, 5705.6f);
  numBytes += cVar_init_f(&cVar_In3P8Ob9, 313.3f);
  numBytes += cBinop_init(&cBinop_ErALCzLC, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_RHzgUMgu, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_Cq1pfjM7, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_ltbeW5jj, 0.0f);
  numBytes += cVar_init_f(&cVar_GODBne8o, 0.0f);
  numBytes += cVar_init_f(&cVar_rNMzVf69, 0.0f);
  numBytes += cVar_init_f(&cVar_NmVZGldt, 0.0f);
  numBytes += cVar_init_f(&cVar_nOYdbUCZ, 0.0f);
  numBytes += cVar_init_f(&cVar_afZS3Lig, 0.0f);
  numBytes += cVar_init_f(&cVar_1ZyuPeHx, 0.0f);
  numBytes += cVar_init_f(&cVar_BL5uwWjS, 0.0f);
  numBytes += cVar_init_f(&cVar_ELSkdrSN, 0.0f);
  numBytes += cVar_init_f(&cVar_CytW3TUX, 0.0f);
  numBytes += cVar_init_f(&cVar_IF0rM8OE, 0.0f);
  numBytes += cVar_init_f(&cVar_s6r7mBYu, 0.0f);
  numBytes += cVar_init_s(&cVar_4zxrmQ4X, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_N0tHSzAl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gQAS2LGX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dVwd303a, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_eHALaulb, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_XmNOquZT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6Vu96kw9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1adF9Pbh, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_HH8qzKMk, 0.0f);
  numBytes += cDelay_init(this, &cDelay_6AHD5lQx, 0.0f);
  numBytes += hTable_init(&hTable_ecm7aEce, 256);
  numBytes += cDelay_init(this, &cDelay_21AjVAIg, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ddUJFv1t, 0.0f);
  numBytes += hTable_init(&hTable_hbN5hlr9, 256);
  numBytes += cVar_init_f(&cVar_lO1WOAYn, 14.0f);
  numBytes += cBinop_init(&cBinop_7co2VrWD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_i9PAF8P1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MrVZNbLr, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_tGHAxRcf, 14.0f);
  numBytes += cBinop_init(&cBinop_D7LIx9Rf, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_TQBWOuWr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6uKl5lal, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_McG6YkHp, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_4cZyZwph, 1, -1);
  numBytes += cVar_init_f(&cVar_KRBC8oES, 0.2f);
  numBytes += cSlice_init(&cSlice_KZxTodVQ, 1, -1);
  numBytes += cVar_init_f(&cVar_K99ZNI8u, 0.0f);
  numBytes += cSlice_init(&cSlice_l4rkk9yO, 1, -1);
  numBytes += cVar_init_f(&cVar_ZFurfJWd, 2.0f);
  numBytes += cSlice_init(&cSlice_BVu9bJCM, 1, -1);
  numBytes += cVar_init_f(&cVar_OB423o0A, 0.5f);
  numBytes += cVar_init_s(&cVar_Yk0moOtE, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_1sqM5xBU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bW0UjTKk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FKRUKgsg, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_XcxK5Snh, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_rGFgVMIZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_M2BAPQa1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pTrTk4g9, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_KWu42cpT, 0.0f);
  numBytes += cDelay_init(this, &cDelay_KFuuUTlW, 0.0f);
  numBytes += hTable_init(&hTable_cqHivfi4, 256);
  numBytes += cDelay_init(this, &cDelay_cLXxqpoF, 0.0f);
  numBytes += cDelay_init(this, &cDelay_NsIkxHOI, 0.0f);
  numBytes += hTable_init(&hTable_wI3XSRy2, 256);
  numBytes += cVar_init_f(&cVar_mv0BXzJf, 14.0f);
  numBytes += cBinop_init(&cBinop_pmiY9y9Y, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_xhvIJwxQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tOfqHuTn, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_NqthXCXl, 14.0f);
  numBytes += cBinop_init(&cBinop_gZ63QgqG, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_tePQbmFk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OkF13VSG, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_oyjVqVrk, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_R2Fiifbe, 1, -1);
  numBytes += cVar_init_f(&cVar_PQ3xnQkG, 0.2f);
  numBytes += cSlice_init(&cSlice_zU4U52KV, 1, -1);
  numBytes += cVar_init_f(&cVar_aJvK3iXP, 0.0f);
  numBytes += cSlice_init(&cSlice_jllfrVBC, 1, -1);
  numBytes += cVar_init_f(&cVar_xQ4tuQUm, 2.0f);
  numBytes += cSlice_init(&cSlice_ostl3bWN, 1, -1);
  numBytes += cVar_init_f(&cVar_KWzA91a1, 0.5f);
  numBytes += cVar_init_s(&cVar_g4aWACnE, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_Z1q59qWj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dkeoo8Ls, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_avPNOStI, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_FxCraoi8, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_dYpoNgU0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_huT75Ljk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PntNxsAA, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_cSSjkhUh, 0.0f);
  numBytes += cDelay_init(this, &cDelay_nyizN9gi, 0.0f);
  numBytes += hTable_init(&hTable_73gc2tIx, 256);
  numBytes += cDelay_init(this, &cDelay_pJlm5a33, 0.0f);
  numBytes += cDelay_init(this, &cDelay_9KsdumbY, 0.0f);
  numBytes += hTable_init(&hTable_C6pUYsQg, 256);
  numBytes += cVar_init_f(&cVar_hAzfD8cj, 14.0f);
  numBytes += cBinop_init(&cBinop_H2aP5rWD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_pL7MCPXd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dFzaKFfU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_kaXTdCr5, 14.0f);
  numBytes += cBinop_init(&cBinop_nFg0iL7B, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Gr8c2p3F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eKOp31Wt, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_qY8hUUKX, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_nTBKb6pr, 1, -1);
  numBytes += cVar_init_f(&cVar_h4HfeEzV, 0.2f);
  numBytes += cSlice_init(&cSlice_4OFwtWdQ, 1, -1);
  numBytes += cVar_init_f(&cVar_lQzffpgp, 0.0f);
  numBytes += cSlice_init(&cSlice_rQ2crSe6, 1, -1);
  numBytes += cVar_init_f(&cVar_ey4puTSB, 2.0f);
  numBytes += cSlice_init(&cSlice_FO7kg8CV, 1, -1);
  numBytes += cVar_init_f(&cVar_QJfR8x7R, 0.5f);
  numBytes += sVarf_init(&sVarf_DOz31INJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iB0caOG3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OGnSk1nZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RuTb7OET, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zG4amzRO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nkoo871k, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_ecm7aEce);
  hTable_free(&hTable_hbN5hlr9);
  hTable_free(&hTable_cqHivfi4);
  hTable_free(&hTable_wI3XSRy2);
  hTable_free(&hTable_73gc2tIx);
  hTable_free(&hTable_C6pUYsQg);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_ecm7aEce; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_hbN5hlr9; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_cqHivfi4; // del-1397-flanger-r
    case 0x578173CB: return &hTable_wI3XSRy2; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_73gc2tIx; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_C6pUYsQg; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ea4E8Ldy_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_h3Mn8KzV_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5VKZ9HiR_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cjl0QoTP_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zS0FWYsk_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yM3gt0yO_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3aVkVCf0_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uCuddKry_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_b04nk1dS_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f7fpqKzh_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jtMD63gY_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BPT06rxJ_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_a9f2qUgr_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WaAkJdEE_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CV7Esst0_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8Nm0XwAd_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LReNmlMw_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TQxiemwN_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_u5YJz6xu_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NrlQgeQN_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bGdmIuRT_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dc4gHky1_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q6UhjniK_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MCkdcjpJ_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_47ETSCbt_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_k933W5Jy_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_doAF7aVl_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Dka84Ncr_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YllDyx8d_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DzmCCkkC_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0zUbxgdL_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tDNZv7jQ_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uviM10uI_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_36orl0wL_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_W0a3rMZs_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S11JsLO3_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WMZ3xPHo_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_agz6xWPl_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O4F3OFh2_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pkmeFHlX_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VcVCdSPA_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OhJQEDQu_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3k41hT8c_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F02qcMb6_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qMSi57oq_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XmwVWaaU_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bMhBSUXt_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dQJeokLw_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ROvoogi2_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_imHiq4Kg_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0RzQP4ZS_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XduQZLfi_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_79b45fo0_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s4HU8KkC_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7RT6oJes_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2DFzVxNZ_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Uv2lMkPI_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_ZovOz8sO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4cSiLAq3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_NSAvrq6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K9iaHmX9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_9yGnwHVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cBv69XXa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_zBRiBy6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EYASaWU8_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CAWoiiti_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LDZDOe3a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3SkrDNIW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Sb0YP5hd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KQCDip2q, 0, m, &cSlice_KQCDip2q_sendMessage);
      break;
    }
    default: {
      cSwitchcase_n7g9FZtt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_KQCDip2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YLrJpmVI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YLrJpmVI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_1YBpiBPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YLrJpmVI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_YLrJpmVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_u5YJz6xu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_fCMdw0oC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_q3ngwJoT_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qmtU2KBO, 0, m, &cIf_qmtU2KBO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_qmtU2KBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dO6Scm5W_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_wa5xe6pU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Mnyj8kU6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_chtWnO8g_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_KGlxeHzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZHcjxyr8, HV_BINOP_POW, 0, m, &cBinop_ZHcjxyr8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZHcjxyr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GnRbp62d, 0, m, &cIf_GnRbp62d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_U111nEpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_xxGaNtS3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_aqFFp0MR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wa5xe6pU, 0, m, &cIf_wa5xe6pU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VbtV3SFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BfGEH8XN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BfGEH8XN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wa5xe6pU, 1, m, &cIf_wa5xe6pU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_chtWnO8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_U111nEpZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Mnyj8kU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_GnRbp62d, 0, m, &cIf_GnRbp62d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xxGaNtS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZHcjxyr8, HV_BINOP_POW, 1, m, &cBinop_ZHcjxyr8_sendMessage);
  cMsg_KGlxeHzV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_GnRbp62d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_bJVmHlgL, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_q3ngwJoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qmtU2KBO, 1, m, &cIf_qmtU2KBO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dO6Scm5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TlJJ9mt1, HV_BINOP_GREATER_THAN, 1, m, &cBinop_TlJJ9mt1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Ikp5TE1, HV_BINOP_EQ, 1, m, &cBinop_9Ikp5TE1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8YXCDowL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4JbDopnl, HV_BINOP_ADD, 0, m, &cBinop_4JbDopnl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4JbDopnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VbtV3SFO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aqFFp0MR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TlJJ9mt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GnRbp62d, 1, m, &cIf_GnRbp62d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9Ikp5TE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FZNlUmI1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_FZNlUmI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bJVmHlgL, m);
}

void Heavy_WSTD_FL3NGR::cCast_FOvV3nOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4JbDopnl, HV_BINOP_ADD, 1, m, &cBinop_4JbDopnl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TlJJ9mt1, HV_BINOP_GREATER_THAN, 0, m, &cBinop_TlJJ9mt1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Ikp5TE1, HV_BINOP_EQ, 0, m, &cBinop_9Ikp5TE1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3XBcF2t2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fCMdw0oC, 0, m, &cVar_fCMdw0oC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mILj4jpO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8YXCDowL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_e5hbszRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_v8flJig2_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_XbrJ7GyY, 0, m, &cIf_XbrJ7GyY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_XbrJ7GyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_X1KsI7Ar_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_G3BfaUlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_jVxk7ps1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_fMvYgybL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_cFmRFR1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zj0nuU3F, HV_BINOP_POW, 0, m, &cBinop_zj0nuU3F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zj0nuU3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n9OmH3kA, 0, m, &cIf_n9OmH3kA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jVV4M25X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_sQM14eng_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TXL57Zfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oATQSRdQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1EqIS2Uj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G3BfaUlU, 0, m, &cIf_G3BfaUlU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oATQSRdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G3BfaUlU, 1, m, &cIf_G3BfaUlU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fMvYgybL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_jVV4M25X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jVxk7ps1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_n9OmH3kA, 0, m, &cIf_n9OmH3kA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sQM14eng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zj0nuU3F, HV_BINOP_POW, 1, m, &cBinop_zj0nuU3F_sendMessage);
  cMsg_cFmRFR1j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_n9OmH3kA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NcOso4wd_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XcKSbz6M_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_1AcMW3DM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_v8flJig2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XbrJ7GyY, 1, m, &cIf_XbrJ7GyY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_X1KsI7Ar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eHF6CkeW, HV_BINOP_GREATER_THAN, 1, m, &cBinop_eHF6CkeW_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6rkp971H, HV_BINOP_EQ, 1, m, &cBinop_6rkp971H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_oCDICoje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6eH18ccO, HV_BINOP_ADD, 0, m, &cBinop_6eH18ccO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6eH18ccO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TXL57Zfr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1EqIS2Uj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eHF6CkeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n9OmH3kA, 1, m, &cIf_n9OmH3kA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6rkp971H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_II3yzTUE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_II3yzTUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NcOso4wd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XcKSbz6M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_1AcMW3DM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_u3rSGnNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6eH18ccO, HV_BINOP_ADD, 1, m, &cBinop_6eH18ccO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eHF6CkeW, HV_BINOP_GREATER_THAN, 0, m, &cBinop_eHF6CkeW_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6rkp971H, HV_BINOP_EQ, 0, m, &cBinop_6rkp971H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fFzdWynN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oCDICoje_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_x538HeES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e5hbszRZ, 0, m, &cVar_e5hbszRZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_NIUfiMLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BQqrzGdZ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_fYp92otv, 0, m, &cIf_fYp92otv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_fYp92otv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BRFq4O9I_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_Ac0sGMDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_vM2cBfQk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_RiDtZKJ0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_otyWOkPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LZkao9Gw, HV_BINOP_POW, 0, m, &cBinop_LZkao9Gw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LZkao9Gw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZEaOUn9v, 0, m, &cIf_ZEaOUn9v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LrXRYxlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_7K3jejzd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ypMsS5xD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ac0sGMDS, 0, m, &cIf_Ac0sGMDS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FNmkHsi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_R78m8C7y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_R78m8C7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ac0sGMDS, 1, m, &cIf_Ac0sGMDS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RiDtZKJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_LrXRYxlV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vM2cBfQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ZEaOUn9v, 0, m, &cIf_ZEaOUn9v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7K3jejzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LZkao9Gw, HV_BINOP_POW, 1, m, &cBinop_LZkao9Gw_sendMessage);
  cMsg_otyWOkPm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_ZEaOUn9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_z2X0AFSh, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_BQqrzGdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fYp92otv, 1, m, &cIf_fYp92otv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BRFq4O9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DKmbz1Dv, HV_BINOP_GREATER_THAN, 1, m, &cBinop_DKmbz1Dv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Y2X9tK4, HV_BINOP_EQ, 1, m, &cBinop_1Y2X9tK4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bgmzUCsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mBd8Fil1, HV_BINOP_ADD, 0, m, &cBinop_mBd8Fil1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mBd8Fil1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FNmkHsi0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ypMsS5xD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DKmbz1Dv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZEaOUn9v, 1, m, &cIf_ZEaOUn9v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1Y2X9tK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_POKtCvpy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_POKtCvpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_z2X0AFSh, m);
}

void Heavy_WSTD_FL3NGR::cCast_wC1LMk8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bgmzUCsW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_5lzHhVfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NIUfiMLd, 0, m, &cVar_NIUfiMLd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_G2c3quxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mBd8Fil1, HV_BINOP_ADD, 1, m, &cBinop_mBd8Fil1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DKmbz1Dv, HV_BINOP_GREATER_THAN, 0, m, &cBinop_DKmbz1Dv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Y2X9tK4, HV_BINOP_EQ, 0, m, &cBinop_1Y2X9tK4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_weFNTngO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_jQqz1FoQ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_BmGuQwFz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_H0lacEeE, 0, m, &cSlice_H0lacEeE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_l9CHCeBB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_H0lacEeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UQ5H9uIF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UQ5H9uIF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_HwyRZcoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UQ5H9uIF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_UQ5H9uIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LReNmlMw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_l9CHCeBB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7qveQi4z, 0, m, &cSlice_7qveQi4z_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Sb0YP5hd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_7qveQi4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vVQ2ce9v_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vVQ2ce9v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_bXKOWz8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vVQ2ce9v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_vVQ2ce9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bGdmIuRT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_n7g9FZtt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_47gzll3K, 0, m, &cSlice_47gzll3K_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LHqmMtHS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_47gzll3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FEkMlHd6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FEkMlHd6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_xdg9NDo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FEkMlHd6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_FEkMlHd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TQxiemwN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_LHqmMtHS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EDEgvUEH, 0, m, &cSlice_EDEgvUEH_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_EDEgvUEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DAmon3Vv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DAmon3Vv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_vw1PIAs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DAmon3Vv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_DAmon3Vv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NrlQgeQN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_o5N0dobQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XLdJbJq6, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_GvNy9F6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FB13jTQf, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_4Ha8PIry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x6vYuA93, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_XrIVXuOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZS3MVA2n, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_bnJTUW02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z83uZGVH, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_OQ1CnFsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OLpFyPWl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_OLpFyPWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BOXWj8eT, HV_BINOP_DIVIDE, 1, m, &cBinop_BOXWj8eT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HMgbzW6o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_0heWdrPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_T6wZGZeB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_eVffmw49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_0heWdrPd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_T6wZGZeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BOXWj8eT, HV_BINOP_DIVIDE, 0, m, &cBinop_BOXWj8eT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HMgbzW6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eVffmw49_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BOXWj8eT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pxXtjheA, HV_BINOP_MULTIPLY, 1, m, &cBinop_pxXtjheA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pxXtjheA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rVEqI9fw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WSFVNjNO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_4aJisSUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_92PachNR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_xgsGeQSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KQLqRDbs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1D33aTqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_uuN304G6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uuN304G6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pxXtjheA, HV_BINOP_MULTIPLY, 0, m, &cBinop_pxXtjheA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DchVDJfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_0e18HSqm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0e18HSqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dZ2yMDiF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_c5ztenVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CKf2NfaQ, 1, m, &cVar_CKf2NfaQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_CKf2NfaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yE61FPlZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_aQZ5Bjv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4hcYfGNP, HV_BINOP_MULTIPLY, 1, m, &cBinop_4hcYfGNP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fV5MeNbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_aQZ5Bjv4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_324T7gpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_T7oy1tbm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_T7oy1tbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ne2gr5Xr, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ne2gr5Xr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OtAltWqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UyFl6PWf, HV_BINOP_MULTIPLY, 1, m, &cBinop_UyFl6PWf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iiiTNooa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OtAltWqd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_H4LlYKyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vGR84zkK, HV_BINOP_MULTIPLY, 1, m, &cBinop_vGR84zkK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_UAMi22v3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_q8q3d0Gl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_q8q3d0Gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nb9TMWyh, HV_BINOP_MULTIPLY, 1, m, &cBinop_Nb9TMWyh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_fX2wzFe3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TvCRiAyd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_1D33aTqS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qkFZ5trf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_TbUO62Uu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_DchVDJfB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rVEqI9fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_4aJisSUh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_WSFVNjNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_xgsGeQSa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_92PachNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MCkdcjpJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_KQLqRDbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Q6UhjniK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_g00yhFGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dc4gHky1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_dZ2yMDiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_vhuKtsug_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vhuKtsug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eINqciv1, HV_BINOP_MULTIPLY, 1, m, &cBinop_eINqciv1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eINqciv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9t4HR025_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9t4HR025_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_g00yhFGI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_yE61FPlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_umzHJ1tV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_umzHJ1tV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rf27Brnj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iEWaUmgQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AHBHHqyf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wsKsUqi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JK0rEjAF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9iTXFIED_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4hcYfGNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o5N0dobQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ne2gr5Xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GvNy9F6n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UyFl6PWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4Ha8PIry_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vGR84zkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XrIVXuOv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Nb9TMWyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bnJTUW02_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_UituTrrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fX2wzFe3, 0, m, &cVar_fX2wzFe3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_McfLtv5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TbUO62Uu, 1, m, &cVar_TbUO62Uu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AHBHHqyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vGR84zkK, HV_BINOP_MULTIPLY, 0, m, &cBinop_vGR84zkK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iEWaUmgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nb9TMWyh, HV_BINOP_MULTIPLY, 0, m, &cBinop_Nb9TMWyh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8wsKsUqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UyFl6PWf, HV_BINOP_MULTIPLY, 0, m, &cBinop_UyFl6PWf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9iTXFIED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4hcYfGNP, HV_BINOP_MULTIPLY, 0, m, &cBinop_4hcYfGNP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JK0rEjAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ne2gr5Xr, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ne2gr5Xr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rf27Brnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_qkFZ5trf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CKf2NfaQ, 0, m, &cVar_CKf2NfaQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TvCRiAyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TbUO62Uu, 0, m, &cVar_TbUO62Uu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Qqwtyquq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W2KQonv4, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_W5WAgtLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t4oBMgmz, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xN1HQgiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gNOLj3oU, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_dD1dskLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iQZSyOuE, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LwFt1292_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4dhr7eVL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_4dhr7eVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_swU5slsg, HV_BINOP_DIVIDE, 1, m, &cBinop_swU5slsg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_by7fmlbJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_58dY5qVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_G5k8QK7J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Xomv2RNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_58dY5qVp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G5k8QK7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_swU5slsg, HV_BINOP_DIVIDE, 0, m, &cBinop_swU5slsg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_by7fmlbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xomv2RNv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_swU5slsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hcnFlZLD, HV_BINOP_MULTIPLY, 1, m, &cBinop_hcnFlZLD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hcnFlZLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rsS9LUuN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RbsPD2mn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_r0qdp0qu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_A0u5R4OK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_0VrRaJk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DGK1umfm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cHScxDDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_qIssmhSo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qIssmhSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hcnFlZLD, HV_BINOP_MULTIPLY, 0, m, &cBinop_hcnFlZLD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_quQ69YH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_zJD4qZjn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zJD4qZjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xPHTkm04_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5db9oCg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r1N5Fw3O, HV_BINOP_MULTIPLY, 1, m, &cBinop_r1N5Fw3O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0oWyd9wh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nLIP089Z, 1, m, &cVar_nLIP089Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZURJipps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4O2fZtjj, HV_BINOP_MULTIPLY, 1, m, &cBinop_4O2fZtjj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8A29q1CP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CyfA42QP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CyfA42QP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XBZwHVyQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_XBZwHVyQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_nLIP089Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1ZIJscU9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_AAyuPqol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wFXYPCcZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_cHScxDDC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CsSYIrq3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_deU8rx9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_quQ69YH3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_RbsPD2mn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_0VrRaJk6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rsS9LUuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_r0qdp0qu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_A0u5R4OK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_doAF7aVl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_DGK1umfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_k933W5Jy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_BdWzR8vS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_47ETSCbt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_xPHTkm04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OPtXZGYl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OPtXZGYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZuVDMuPN, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZuVDMuPN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZuVDMuPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SaLRp61H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SaLRp61H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BdWzR8vS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_1ZIJscU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9qkhWzUZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9qkhWzUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J3mJGqJq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eXesfQAy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L3vPI2DB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GU1Mkfpx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8Us4gGU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qqwtyquq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_r1N5Fw3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W5WAgtLm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_4O2fZtjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xN1HQgiX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XBZwHVyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dD1dskLJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_AinG2KlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_deU8rx9M, 1, m, &cVar_deU8rx9M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EuHektHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AAyuPqol, 0, m, &cVar_AAyuPqol_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wFXYPCcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_deU8rx9M, 0, m, &cVar_deU8rx9M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CsSYIrq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nLIP089Z, 0, m, &cVar_nLIP089Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_L3vPI2DB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r1N5Fw3O, HV_BINOP_MULTIPLY, 0, m, &cBinop_r1N5Fw3O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_J3mJGqJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XBZwHVyQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_XBZwHVyQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GU1Mkfpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Us4gGU7, HV_BINOP_MULTIPLY, 0, m, &cBinop_8Us4gGU7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_eXesfQAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4O2fZtjj, HV_BINOP_MULTIPLY, 0, m, &cBinop_4O2fZtjj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_y29Ns3WD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jdhDHsGm, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LVM0xWqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_avsmylyo, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_7Saaxb0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QPHzUIM0, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_9aKvIZZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3jAYHYcw, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_l1mUJiup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3X6jcika, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_NGaHfCTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3xB5LYcZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_3xB5LYcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vdsJAA3N, HV_BINOP_DIVIDE, 1, m, &cBinop_vdsJAA3N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AwPOpbby_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_ytAUTwSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_OneZmPPv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_aQe3MOG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ytAUTwSm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OneZmPPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vdsJAA3N, HV_BINOP_DIVIDE, 0, m, &cBinop_vdsJAA3N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AwPOpbby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aQe3MOG4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vdsJAA3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Od8QpTBS, HV_BINOP_MULTIPLY, 1, m, &cBinop_Od8QpTBS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Od8QpTBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4ydkC8hc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nJMGsa9q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_uqnSx9Gj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_46xoLHAL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_w3RvjREM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NesHrF9S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3Gq328PG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_9QfOH60m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9QfOH60m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Od8QpTBS, HV_BINOP_MULTIPLY, 0, m, &cBinop_Od8QpTBS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DIbYDa5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_0mBIUMgu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0mBIUMgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ii9H5MoM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_u5I99oIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4CrtcssM, HV_BINOP_MULTIPLY, 1, m, &cBinop_4CrtcssM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7MLhsur2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wMj2ynfC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wMj2ynfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_u5I99oIV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1fXlFTew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zacCrXA8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zacCrXA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3FqfOnFR, HV_BINOP_MULTIPLY, 1, m, &cBinop_3FqfOnFR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_y6frkAeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_obxYA3hz, HV_BINOP_MULTIPLY, 1, m, &cBinop_obxYA3hz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7cov59um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VevKsbNZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VevKsbNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_y6frkAeZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ShUkWpFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WSYoG2th, 1, m, &cVar_WSYoG2th_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MPoAwvT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RqQLuqyG, HV_BINOP_MULTIPLY, 1, m, &cBinop_RqQLuqyG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bP6zoYSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_c1LJyYTG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_c1LJyYTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xcnNDK7e, HV_BINOP_MULTIPLY, 1, m, &cBinop_xcnNDK7e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_WSYoG2th_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GfOs8Rb2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_9B2nbh3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_63Xhi5ny_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_3Gq328PG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Yp6REYew_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_8K8KnprX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_DIbYDa5z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nJMGsa9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_w3RvjREM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4ydkC8hc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_uqnSx9Gj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_46xoLHAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DzmCCkkC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_NesHrF9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YllDyx8d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_GPd0l2F2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Dka84Ncr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Ii9H5MoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_V8TbolTi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_V8TbolTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dEdxLiK6, HV_BINOP_MULTIPLY, 1, m, &cBinop_dEdxLiK6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dEdxLiK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5FfybDqQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5FfybDqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GPd0l2F2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_GfOs8Rb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fcOEA9jF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fcOEA9jF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dHbkfKbO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w07Idvp2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YpPg0v4I_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WJjoVz4z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dOfPFvHD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MzezzzBt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4CrtcssM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y29Ns3WD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3FqfOnFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LVM0xWqM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_obxYA3hz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Saaxb0N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_RqQLuqyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9aKvIZZu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xcnNDK7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l1mUJiup_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_o4TAhRdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9B2nbh3N, 0, m, &cVar_9B2nbh3N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_R1yM0bRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8K8KnprX, 1, m, &cVar_8K8KnprX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_WJjoVz4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_obxYA3hz, HV_BINOP_MULTIPLY, 0, m, &cBinop_obxYA3hz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dOfPFvHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3FqfOnFR, HV_BINOP_MULTIPLY, 0, m, &cBinop_3FqfOnFR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MzezzzBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4CrtcssM, HV_BINOP_MULTIPLY, 0, m, &cBinop_4CrtcssM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_w07Idvp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xcnNDK7e, HV_BINOP_MULTIPLY, 0, m, &cBinop_xcnNDK7e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dHbkfKbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_YpPg0v4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RqQLuqyG, HV_BINOP_MULTIPLY, 0, m, &cBinop_RqQLuqyG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_63Xhi5ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8K8KnprX, 0, m, &cVar_8K8KnprX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Yp6REYew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WSYoG2th, 0, m, &cVar_WSYoG2th_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NcOso4wd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_weFNTngO, 1, m, &cIf_weFNTngO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Wuwvd54r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jQqz1FoQ, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XcKSbz6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wuwvd54r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1AcMW3DM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_weFNTngO, 0, m, &cIf_weFNTngO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_6zTxuszQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fkb8CLcr, 0, m, &cSlice_fkb8CLcr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zj7bdc0I_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_fkb8CLcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dYKKxZfB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dYKKxZfB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_XRFS5uzn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dYKKxZfB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_dYKKxZfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uviM10uI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_vYbOPsDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_laqrF9rq_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_93BPAayp, 0, m, &cIf_93BPAayp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_93BPAayp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_So7fwCdm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_SgMvNx8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_l5IBAAS5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_FhOYD9em_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_d4i8t4Bo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FJVVoUDL, HV_BINOP_POW, 0, m, &cBinop_FJVVoUDL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FJVVoUDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gF5KVfuu, 0, m, &cIf_gF5KVfuu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1Hg6kQK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_zgfe0YN1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7HEbZaya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SgMvNx8O, 0, m, &cIf_SgMvNx8O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MLzJ4a67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WGPTkwXm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WGPTkwXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SgMvNx8O, 1, m, &cIf_SgMvNx8O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FhOYD9em_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_1Hg6kQK2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_l5IBAAS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_gF5KVfuu, 0, m, &cIf_gF5KVfuu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zgfe0YN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FJVVoUDL, HV_BINOP_POW, 1, m, &cBinop_FJVVoUDL_sendMessage);
  cMsg_d4i8t4Bo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_gF5KVfuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_lrWlTZAZ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_laqrF9rq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_93BPAayp, 1, m, &cIf_93BPAayp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_So7fwCdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_klmVxww7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_klmVxww7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0yqvKP3z, HV_BINOP_EQ, 1, m, &cBinop_0yqvKP3z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XIOYk1QJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8sTtfl3i, HV_BINOP_ADD, 0, m, &cBinop_8sTtfl3i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8sTtfl3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MLzJ4a67_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7HEbZaya_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_klmVxww7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gF5KVfuu, 1, m, &cIf_gF5KVfuu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0yqvKP3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bSnGpCnj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_bSnGpCnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lrWlTZAZ, m);
}

void Heavy_WSTD_FL3NGR::cCast_Ch2jjEp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XIOYk1QJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_YRqAefZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vYbOPsDL, 0, m, &cVar_vYbOPsDL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TkXT1z9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8sTtfl3i, HV_BINOP_ADD, 1, m, &cBinop_8sTtfl3i_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_klmVxww7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_klmVxww7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0yqvKP3z, HV_BINOP_EQ, 0, m, &cBinop_0yqvKP3z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_IiWsqxSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_duzW1b8X_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_HJPrHqGt, 0, m, &cIf_HJPrHqGt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_HJPrHqGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8LIoo1TB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_nuDmCNFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_EG0x7b8b_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_B95U2XYk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_YdRvL4GA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wz6uvkCa, HV_BINOP_POW, 0, m, &cBinop_Wz6uvkCa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Wz6uvkCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_c27ct0Tg, 0, m, &cIf_c27ct0Tg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GIut1EUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Entjfylj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EINmBTNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UGYqdxoJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jOPtlk9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nuDmCNFf, 0, m, &cIf_nuDmCNFf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UGYqdxoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nuDmCNFf, 1, m, &cIf_nuDmCNFf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_B95U2XYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_GIut1EUB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EG0x7b8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_c27ct0Tg, 0, m, &cIf_c27ct0Tg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Entjfylj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wz6uvkCa, HV_BINOP_POW, 1, m, &cBinop_Wz6uvkCa_sendMessage);
  cMsg_YdRvL4GA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_c27ct0Tg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3GwwrNd5_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9e3BAiZi_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_BR2mqRDT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_duzW1b8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HJPrHqGt, 1, m, &cIf_HJPrHqGt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8LIoo1TB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cBwN9uZo, HV_BINOP_GREATER_THAN, 1, m, &cBinop_cBwN9uZo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_F1SVR8vh, HV_BINOP_EQ, 1, m, &cBinop_F1SVR8vh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_M5ZGJHhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yre5JBsn, HV_BINOP_ADD, 0, m, &cBinop_yre5JBsn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yre5JBsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EINmBTNe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jOPtlk9K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cBwN9uZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_c27ct0Tg, 1, m, &cIf_c27ct0Tg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_F1SVR8vh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MBa1OKW7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_MBa1OKW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3GwwrNd5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9e3BAiZi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_BR2mqRDT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vi5ggtu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IiWsqxSy, 0, m, &cVar_IiWsqxSy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_K0D1hVl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yre5JBsn, HV_BINOP_ADD, 1, m, &cBinop_yre5JBsn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cBwN9uZo, HV_BINOP_GREATER_THAN, 0, m, &cBinop_cBwN9uZo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_F1SVR8vh, HV_BINOP_EQ, 0, m, &cBinop_F1SVR8vh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fpYlnHAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M5ZGJHhs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_IcbZFiAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XzHAKlFY_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_8KyDtSzE, 0, m, &cIf_8KyDtSzE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_8KyDtSzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UHcBl2FO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_Z7L6oIY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_o5VgCeUG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_mkW6Kbom_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_IMKyt1tB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9I4dPuBe, HV_BINOP_POW, 0, m, &cBinop_9I4dPuBe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9I4dPuBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WgES5CZe, 0, m, &cIf_WgES5CZe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_64t9mnlc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_tNEycrEm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wdDdyGSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z7L6oIY4, 0, m, &cIf_Z7L6oIY4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_i53VnqCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5lHfLSmt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5lHfLSmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z7L6oIY4, 1, m, &cIf_Z7L6oIY4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mkW6Kbom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_64t9mnlc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_o5VgCeUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_WgES5CZe, 0, m, &cIf_WgES5CZe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tNEycrEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9I4dPuBe, HV_BINOP_POW, 1, m, &cBinop_9I4dPuBe_sendMessage);
  cMsg_IMKyt1tB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_WgES5CZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_CjjxqviT, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_XzHAKlFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8KyDtSzE, 1, m, &cIf_8KyDtSzE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UHcBl2FO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p2GAE1zy, HV_BINOP_GREATER_THAN, 1, m, &cBinop_p2GAE1zy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uNflJNa7, HV_BINOP_EQ, 1, m, &cBinop_uNflJNa7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_G43fJwUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MkO0ckzb, HV_BINOP_ADD, 0, m, &cBinop_MkO0ckzb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MkO0ckzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i53VnqCv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wdDdyGSC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_p2GAE1zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WgES5CZe, 1, m, &cIf_WgES5CZe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uNflJNa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_slf5iQ7E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_slf5iQ7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CjjxqviT, m);
}

void Heavy_WSTD_FL3NGR::cCast_q9Z6i29g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G43fJwUL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_BmL692p6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IcbZFiAf, 0, m, &cVar_IcbZFiAf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_R7anBLg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MkO0ckzb, HV_BINOP_ADD, 1, m, &cBinop_MkO0ckzb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_p2GAE1zy, HV_BINOP_GREATER_THAN, 0, m, &cBinop_p2GAE1zy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uNflJNa7, HV_BINOP_EQ, 0, m, &cBinop_uNflJNa7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_oBl6AapX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_wOo0RVca, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_CQjSSbZZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fdI14mGp, 0, m, &cSlice_fdI14mGp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vS3O6Jmz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_fdI14mGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Mh159MEy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Mh159MEy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_vN1n7vP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Mh159MEy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Mh159MEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0zUbxgdL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_vS3O6Jmz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2hNfK1nE, 0, m, &cSlice_2hNfK1nE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6zTxuszQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_2hNfK1nE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_840wGWNj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_840wGWNj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_04Bgmd2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_840wGWNj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_840wGWNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_W0a3rMZs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_zj7bdc0I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ephck8wl, 0, m, &cSlice_Ephck8wl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6XyweJJx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Ephck8wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MavL99l3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MavL99l3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_doPLeQVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MavL99l3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_MavL99l3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tDNZv7jQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_6XyweJJx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SiMlMIXi, 0, m, &cSlice_SiMlMIXi_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_SiMlMIXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rstoYpJM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rstoYpJM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_NyhFtEfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rstoYpJM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_rstoYpJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_36orl0wL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_1NPqv7DX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RU5HxvtD, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6csdLBXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_epRe6M1g, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_zzjqUVN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ku9hKyVk, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_I8gr4ktk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Krauvyn8, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mV6mMIl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L7ubCZ9f, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_rxaFVeVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7mU68vH4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_7mU68vH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CCXhJgzV, HV_BINOP_DIVIDE, 1, m, &cBinop_CCXhJgzV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r5hOobDh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_LBuFRFvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_nJ7sxuAi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GCVGLipG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_LBuFRFvL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nJ7sxuAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CCXhJgzV, HV_BINOP_DIVIDE, 0, m, &cBinop_CCXhJgzV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_r5hOobDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GCVGLipG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CCXhJgzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ih4PpUJG, HV_BINOP_MULTIPLY, 1, m, &cBinop_ih4PpUJG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ih4PpUJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TOHSE4JQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9r0x7tTX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_iRr1DFn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_A8Ff2ea8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_vWqIbvWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XBHccxG7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UQLFEpCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_pRnao7jF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pRnao7jF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ih4PpUJG, HV_BINOP_MULTIPLY, 0, m, &cBinop_ih4PpUJG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VvEdDSJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_HQ9hCreu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HQ9hCreu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w3puvCNh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_RSw1Lita_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KYUqNqvp, 1, m, &cVar_KYUqNqvp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_KYUqNqvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jT5DdFmX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vIN3keoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_heFp9rxe, HV_BINOP_MULTIPLY, 1, m, &cBinop_heFp9rxe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ly6iHunE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vIN3keoD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_otYM9Xb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_sKhZQI9b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sKhZQI9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L7OiNMFB, HV_BINOP_MULTIPLY, 1, m, &cBinop_L7OiNMFB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FRMANLCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pAJTfjT0, HV_BINOP_MULTIPLY, 1, m, &cBinop_pAJTfjT0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7EQT1gZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FRMANLCK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6AuL5CtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z3jdo7He, HV_BINOP_MULTIPLY, 1, m, &cBinop_z3jdo7He_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5PEdlHuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_d2er51cf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_d2er51cf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7dORlf1w, HV_BINOP_MULTIPLY, 1, m, &cBinop_7dORlf1w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Nf8CrU7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uzxsSD6h_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_UQLFEpCh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0W005pst_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_kaMk0Kw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_VvEdDSJ6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TOHSE4JQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_iRr1DFn3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9r0x7tTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_vWqIbvWC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_A8Ff2ea8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_agz6xWPl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_XBHccxG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WMZ3xPHo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_kfsmlXMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_S11JsLO3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_w3puvCNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lenLWiBb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lenLWiBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_beZJgt7B, HV_BINOP_MULTIPLY, 1, m, &cBinop_beZJgt7B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_beZJgt7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RGSobaGr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RGSobaGr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kfsmlXMi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_jT5DdFmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UUaKa2x6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UUaKa2x6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LZjBA9Sb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tAsxFdUo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SIzJXcxW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wvBEpQzR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6IiM4FCv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xmrip1aU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_heFp9rxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1NPqv7DX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_L7OiNMFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6csdLBXa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_pAJTfjT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zzjqUVN7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_z3jdo7He_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I8gr4ktk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_7dORlf1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mV6mMIl0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_E62Yo9Gd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Nf8CrU7B, 0, m, &cVar_Nf8CrU7B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pEIYa5nC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kaMk0Kw6, 1, m, &cVar_kaMk0Kw6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_SIzJXcxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z3jdo7He, HV_BINOP_MULTIPLY, 0, m, &cBinop_z3jdo7He_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tAsxFdUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7dORlf1w, HV_BINOP_MULTIPLY, 0, m, &cBinop_7dORlf1w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LZjBA9Sb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_Xmrip1aU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_heFp9rxe, HV_BINOP_MULTIPLY, 0, m, &cBinop_heFp9rxe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wvBEpQzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pAJTfjT0, HV_BINOP_MULTIPLY, 0, m, &cBinop_pAJTfjT0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6IiM4FCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L7OiNMFB, HV_BINOP_MULTIPLY, 0, m, &cBinop_L7OiNMFB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_uzxsSD6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kaMk0Kw6, 0, m, &cVar_kaMk0Kw6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0W005pst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KYUqNqvp, 0, m, &cVar_KYUqNqvp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Q02OebCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KlqGuDxv, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_zQYa4bBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WH9VXLdd, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_63ZhIvhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p37h2B2U, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_RrugWStM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GgjSUe53, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_3R6IlNN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7WYObQI1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_7WYObQI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XRkoNLdA, HV_BINOP_DIVIDE, 1, m, &cBinop_XRkoNLdA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3SFxAf9A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_3MkOueGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_JGBGOqYs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rvKMsmAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_3MkOueGW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JGBGOqYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XRkoNLdA, HV_BINOP_DIVIDE, 0, m, &cBinop_XRkoNLdA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3SFxAf9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rvKMsmAa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XRkoNLdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kMkQMPHb, HV_BINOP_MULTIPLY, 1, m, &cBinop_kMkQMPHb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kMkQMPHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TpLkdoO3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HqXK2d40_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_gjAYJpdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nqrmjHqd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_HQEcekFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RnUqQkhD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OP5zwG1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_XLg2GvMM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XLg2GvMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kMkQMPHb, HV_BINOP_MULTIPLY, 0, m, &cBinop_kMkQMPHb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_J63nqRbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_FhhQdvlq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FhhQdvlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0HrddAPF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_eK2NugB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I5CeLgT4, HV_BINOP_MULTIPLY, 1, m, &cBinop_I5CeLgT4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_c8Lyz7NI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_q6KCu910, 1, m, &cVar_q6KCu910_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_E6nVhmPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L0igb0pG, HV_BINOP_MULTIPLY, 1, m, &cBinop_L0igb0pG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1LWbuXcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Hk9f7ypK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Hk9f7ypK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ghCtk7lM, HV_BINOP_MULTIPLY, 1, m, &cBinop_ghCtk7lM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_q6KCu910_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8ysfyFeW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_EtsbaGhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cCt6TSlo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_OP5zwG1M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7vpePTjV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_JZbew8m9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_J63nqRbp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TpLkdoO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_gjAYJpdV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HqXK2d40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_HQEcekFs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_nqrmjHqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VcVCdSPA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_RnUqQkhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pkmeFHlX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_qnPQm8H7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_O4F3OFh2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_0HrddAPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tLNId08L_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tLNId08L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3etkvjpq, HV_BINOP_MULTIPLY, 1, m, &cBinop_3etkvjpq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3etkvjpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_G0iq2PTS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G0iq2PTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qnPQm8H7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_8ysfyFeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_T6ZcZA6p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_T6ZcZA6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VXjpyoUk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AU4eftxn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FrgOBSOu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R83sJdrP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_afSFSWoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q02OebCH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_I5CeLgT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zQYa4bBn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_L0igb0pG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_63ZhIvhF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ghCtk7lM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RrugWStM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_YeWTZJbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EtsbaGhU, 0, m, &cVar_EtsbaGhU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iV3CR9z7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JZbew8m9, 1, m, &cVar_JZbew8m9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7vpePTjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_q6KCu910, 0, m, &cVar_q6KCu910_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cCt6TSlo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JZbew8m9, 0, m, &cVar_JZbew8m9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AU4eftxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L0igb0pG, HV_BINOP_MULTIPLY, 0, m, &cBinop_L0igb0pG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_R83sJdrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_afSFSWoJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_afSFSWoJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FrgOBSOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I5CeLgT4, HV_BINOP_MULTIPLY, 0, m, &cBinop_I5CeLgT4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VXjpyoUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ghCtk7lM, HV_BINOP_MULTIPLY, 0, m, &cBinop_ghCtk7lM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CzJmXEmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yPfTn93o, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_dFf1U1Pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LP2II8li, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_AExspXTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dsif3AWG, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_eKuIXUpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5PnBOGPw, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_OiQCkIW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SEltjmPJ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mnUcgyHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7EMbICCj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_7EMbICCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UUYqntEq, HV_BINOP_DIVIDE, 1, m, &cBinop_UUYqntEq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_beyYytJI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_VstPvUDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_NmAtO83D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mwGECRmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_VstPvUDq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NmAtO83D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UUYqntEq, HV_BINOP_DIVIDE, 0, m, &cBinop_UUYqntEq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_beyYytJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mwGECRmW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UUYqntEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V7RSxp0b, HV_BINOP_MULTIPLY, 1, m, &cBinop_V7RSxp0b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_V7RSxp0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VLKeE1h9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KGdK5raV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_7SNHJcj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ToGOnjXS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_yq76DiPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xvhY2s5H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KuGQdqFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_yLpgQfFm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yLpgQfFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V7RSxp0b, HV_BINOP_MULTIPLY, 0, m, &cBinop_V7RSxp0b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_39dW0dPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_vTLNPetx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vTLNPetx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vcgOVsca_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QrE4IXHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pJyouG42, HV_BINOP_MULTIPLY, 1, m, &cBinop_pJyouG42_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_K3sOOJoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CCCOs1is_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CCCOs1is_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QrE4IXHL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QcqdtN0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UpIwen8w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UpIwen8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MrN4e4d4, HV_BINOP_MULTIPLY, 1, m, &cBinop_MrN4e4d4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_W6NUPI0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5POI1bQi, HV_BINOP_MULTIPLY, 1, m, &cBinop_5POI1bQi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9EyZEz4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qL18Ibm4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qL18Ibm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_W6NUPI0q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_19dcUCpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TzeaOnfo, 1, m, &cVar_TzeaOnfo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sjEOeHh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p2C0SpsH, HV_BINOP_MULTIPLY, 1, m, &cBinop_p2C0SpsH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2QzXmxDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bv7Tb4WE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bv7Tb4WE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nItNXOrT, HV_BINOP_MULTIPLY, 1, m, &cBinop_nItNXOrT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_TzeaOnfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tXhlxSfM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_0N608zZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2yMqPZlC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_KuGQdqFh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r06CL1Ul_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_jc3PPlYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_39dW0dPE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KGdK5raV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_yq76DiPY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VLKeE1h9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_7SNHJcj3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_ToGOnjXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_F02qcMb6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_xvhY2s5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3k41hT8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_vhzXbh1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OhJQEDQu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_vcgOVsca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uJZlYTxo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uJZlYTxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7903jqqL, HV_BINOP_MULTIPLY, 1, m, &cBinop_7903jqqL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7903jqqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9HhTpMGy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9HhTpMGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vhzXbh1N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_tXhlxSfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_oufVjZ7j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oufVjZ7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q9FZpAWc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UKZUNsxt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CfzRbVpB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1viEgzQ0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mSUkoaG4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AUpmNb5J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pJyouG42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CzJmXEmQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MrN4e4d4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dFf1U1Pg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5POI1bQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AExspXTF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_p2C0SpsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eKuIXUpN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nItNXOrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OiQCkIW7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_qSn2druB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jc3PPlYf, 1, m, &cVar_jc3PPlYf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_93WTWTq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0N608zZH, 0, m, &cVar_0N608zZH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UKZUNsxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nItNXOrT, HV_BINOP_MULTIPLY, 0, m, &cBinop_nItNXOrT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AUpmNb5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pJyouG42, HV_BINOP_MULTIPLY, 0, m, &cBinop_pJyouG42_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1viEgzQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5POI1bQi, HV_BINOP_MULTIPLY, 0, m, &cBinop_5POI1bQi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_q9FZpAWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_CfzRbVpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p2C0SpsH, HV_BINOP_MULTIPLY, 0, m, &cBinop_p2C0SpsH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mSUkoaG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MrN4e4d4, HV_BINOP_MULTIPLY, 0, m, &cBinop_MrN4e4d4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_r06CL1Ul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TzeaOnfo, 0, m, &cVar_TzeaOnfo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2yMqPZlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jc3PPlYf, 0, m, &cVar_jc3PPlYf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3GwwrNd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oBl6AapX, 1, m, &cIf_oBl6AapX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_SCfO8BA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wOo0RVca, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9e3BAiZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SCfO8BA0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BR2mqRDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oBl6AapX, 0, m, &cIf_oBl6AapX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_oJgqxgDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHzgUMgu, HV_BINOP_DIVIDE, 0, m, &cBinop_RHzgUMgu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_In3P8Ob9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ErALCzLC, HV_BINOP_DIVIDE, 1, m, &cBinop_ErALCzLC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHzgUMgu, HV_BINOP_DIVIDE, 1, m, &cBinop_RHzgUMgu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_cU4ENmjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cq1pfjM7, HV_BINOP_DIVIDE, 0, m, &cBinop_Cq1pfjM7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_kTv7mDsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cq1pfjM7, HV_BINOP_DIVIDE, 1, m, &cBinop_Cq1pfjM7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CAWoiiti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_In3P8Ob9, 0, m, &cVar_In3P8Ob9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3SkrDNIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ErALCzLC, HV_BINOP_DIVIDE, 0, m, &cBinop_ErALCzLC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LDZDOe3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oJgqxgDq, 0, m, &cVar_oJgqxgDq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ErALCzLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_cU4ENmjB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RHzgUMgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_kTv7mDsa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Cq1pfjM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_PaO38uZs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_4QzaLAW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_tbnvtWww_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lb9TK5X9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_petv7iTx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PaO38uZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_lb9TK5X9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_petv7iTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_4QzaLAW0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tbnvtWww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SC2hxDvM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ltbeW5jj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M9cnVves_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_GODBne8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZgdxoIv2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_rNMzVf69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xARcb0f7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_NmVZGldt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jWCPQYVy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_nOYdbUCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZmuXOtr8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_afZS3Lig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F85cPO2P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_1ZyuPeHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JkKCg4xc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_BL5uwWjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NX7K5NUG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ELSkdrSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nQ8y8TnF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_CytW3TUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hGbG8uvu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_IF0rM8OE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MdFBlMiv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_s6r7mBYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ftrN8Ix2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nYrMwLNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_1g9G6U1b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1g9G6U1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_yNFmI11y, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_yGL0j7qD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HO9eEDEx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_HO9eEDEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_8YJAzIWS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_4zxrmQ4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v9DIMnUh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_MwfaCD7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_EsW5xsAS_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_N0tHSzAl, m);
}

void Heavy_WSTD_FL3NGR::cBinop_8YJAzIWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gQAS2LGX, m);
}

void Heavy_WSTD_FL3NGR::cMsg_v9DIMnUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MwfaCD7c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EsW5xsAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dVwd303a, m);
}

void Heavy_WSTD_FL3NGR::cMsg_WiXhjYQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PftQOKLo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_PftQOKLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Cye1c8WV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_eHALaulb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sP23ntjj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_6W1rXn71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_igtsznVa_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XmNOquZT, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Cye1c8WV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6Vu96kw9, m);
}

void Heavy_WSTD_FL3NGR::cMsg_sP23ntjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6W1rXn71_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_igtsznVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_1adF9Pbh, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rR7UyAGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5ITERylz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5ITERylz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_IKv85GRe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_EZeWQVPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IOGkIWgr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_3kaXKJ1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PaeKfSUi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IKv85GRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_A2VQP7e9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_A2VQP7e9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GUoUDoyv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fAKGsIiu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GUoUDoyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xk3YXSDH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fAKGsIiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r1dixEkl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xk3YXSDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_T7bdlEr4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_r1dixEkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JO1fLL0p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JO1fLL0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sbKSWV0y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_T7bdlEr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_EZeWQVPT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sbKSWV0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_3kaXKJ1h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_96f3GLF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_b7ncE14s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_b7ncE14s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FOe0NoII_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_b3RkPtOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CN0uUbQR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_CN0uUbQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bsg2JnPF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_HH8qzKMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HH8qzKMk, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6AHD5lQx, 0, m, &cDelay_6AHD5lQx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HH8qzKMk, 0, m, &cDelay_HH8qzKMk_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1CQQ9hQW, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_6AHD5lQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6AHD5lQx, m);
  cMsg_Cq8H5iWc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Dwgv2v1Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_3GFshUeq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_bdPB4MlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zOx12HBt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_ecm7aEce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IsGKHFZN_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HH8qzKMk, 2, m, &cDelay_HH8qzKMk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y38dDZ2Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zOx12HBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ecm7aEce, 0, m, &hTable_ecm7aEce_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bsg2JnPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_bdPB4MlB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Cq8H5iWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ecm7aEce, 0, m, &hTable_ecm7aEce_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Y38dDZ2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HH8qzKMk, 0, m, &cDelay_HH8qzKMk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_IsGKHFZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_6AHD5lQx, 2, m, &cDelay_6AHD5lQx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3GFshUeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1CQQ9hQW, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6W3tskl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YMoxsp6G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_YMoxsp6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_FYb1yCUy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_21AjVAIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_21AjVAIg, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ddUJFv1t, 0, m, &cDelay_ddUJFv1t_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_21AjVAIg, 0, m, &cDelay_21AjVAIg_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_d1UnsjEj, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_ddUJFv1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ddUJFv1t, m);
  cMsg_BoYEh9ey_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_5fehOVJv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_8sCZMMki_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_lW8sYIXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sdnOCEME_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_hbN5hlr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OKIHzsci_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_21AjVAIg, 2, m, &cDelay_21AjVAIg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lemt74jc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sdnOCEME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_hbN5hlr9, 0, m, &hTable_hbN5hlr9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FYb1yCUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_lW8sYIXP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_BoYEh9ey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_hbN5hlr9, 0, m, &hTable_hbN5hlr9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lemt74jc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_21AjVAIg, 0, m, &cDelay_21AjVAIg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OKIHzsci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ddUJFv1t, 2, m, &cDelay_ddUJFv1t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8sCZMMki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_d1UnsjEj, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_lO1WOAYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7co2VrWD, HV_BINOP_MULTIPLY, 0, m, &cBinop_7co2VrWD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QFuJccmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_To9iYXUO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_To9iYXUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KV8EECjM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_7co2VrWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Pm3uQUqv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_P9Ba1Zml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7co2VrWD, HV_BINOP_MULTIPLY, 1, m, &cBinop_7co2VrWD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KV8EECjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_P9Ba1Zml_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Pm3uQUqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_RKqEC5ez_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RKqEC5ez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_oi1jN5H4_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MrVZNbLr, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oi1jN5H4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_i9PAF8P1, m);
}

void Heavy_WSTD_FL3NGR::cVar_tGHAxRcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D7LIx9Rf, HV_BINOP_MULTIPLY, 0, m, &cBinop_D7LIx9Rf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_SUSlXnbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1DsUbjE8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_1DsUbjE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VznRUQil_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_D7LIx9Rf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_B9L1zju0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mP6Ap06o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D7LIx9Rf, HV_BINOP_MULTIPLY, 1, m, &cBinop_D7LIx9Rf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VznRUQil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mP6Ap06o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_B9L1zju0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_jQg2WKvI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jQg2WKvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_gJ8GqcPj_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6uKl5lal, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gJ8GqcPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TQBWOuWr, m);
}

void Heavy_WSTD_FL3NGR::cMsg_FOe0NoII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hDjhdwA0, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_NwJvcVgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_ounQmMop_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_WV3dNO3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_NwJvcVgw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lsgjuVZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bZoLXvmv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wbtTzV6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_t6R5ZaRk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_t6R5ZaRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_McG6YkHp, HV_BINOP_MULTIPLY, 1, m, &cBinop_McG6YkHp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bZoLXvmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_wbtTzV6S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_McG6YkHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0zyZCwYF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ounQmMop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_McG6YkHp, HV_BINOP_MULTIPLY, 0, m, &cBinop_McG6YkHp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0zyZCwYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8AuUDiTO, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_GCyAY35p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_ys73MSqX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ys73MSqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lsgjuVZK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WV3dNO3u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_V3g7m9C0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4cZyZwph, 0, m, &cSlice_4cZyZwph_sendMessage);
      break;
    }
    default: {
      cSwitchcase_D2QbKrhA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_4cZyZwph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_uHBHFdUr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_uHBHFdUr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_KRBC8oES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uHBHFdUr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_uHBHFdUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XmwVWaaU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_D2QbKrhA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KZxTodVQ, 0, m, &cSlice_KZxTodVQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IhWu34PK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_KZxTodVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kP34KhNg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kP34KhNg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_K99ZNI8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kP34KhNg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_kP34KhNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qMSi57oq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_IhWu34PK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_l4rkk9yO, 0, m, &cSlice_l4rkk9yO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_34WdyYKu_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_l4rkk9yO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kwANZsWR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kwANZsWR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ZFurfJWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kwANZsWR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_kwANZsWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dQJeokLw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_34WdyYKu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BVu9bJCM, 0, m, &cSlice_BVu9bJCM_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_BVu9bJCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cXZkCxCX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cXZkCxCX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_OB423o0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cXZkCxCX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_cXZkCxCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bMhBSUXt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_IOGkIWgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GRA5D9rs, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_PaeKfSUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FLVS4wT6, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_WCzcqBow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rKe3NIJt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rKe3NIJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_ZnIrTMyZ, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_FpaM0vJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HeCgDNOv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_HeCgDNOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_m94xWs1b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Yk0moOtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i5yuqeho_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_QeoWvD9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_A0d9yrZD_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1sqM5xBU, m);
}

void Heavy_WSTD_FL3NGR::cBinop_m94xWs1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bW0UjTKk, m);
}

void Heavy_WSTD_FL3NGR::cMsg_i5yuqeho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QeoWvD9t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_A0d9yrZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FKRUKgsg, m);
}

void Heavy_WSTD_FL3NGR::cMsg_yNVQYjgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Z7OZBXth_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Z7OZBXth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gZgaFCHy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_XcxK5Snh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WePbvyxN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_xm7KWRfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ZtCx94c9_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rGFgVMIZ, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gZgaFCHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_M2BAPQa1, m);
}

void Heavy_WSTD_FL3NGR::cMsg_WePbvyxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xm7KWRfO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZtCx94c9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pTrTk4g9, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KVB2FfdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6X7kynnl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6X7kynnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_bkmRAdQe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_rdvSpAsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rdxKkPv9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_U0GDfBKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8c8SK7zE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_bkmRAdQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_k2eL8ZDp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_k2eL8ZDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MTaRus8h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dreAgnT3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MTaRus8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_I7nCGMe4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dreAgnT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3dZLcorE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_I7nCGMe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ztwywPI1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3dZLcorE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9lS9t2Ng_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9lS9t2Ng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ck6ORxFf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ztwywPI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_rdvSpAsR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ck6ORxFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_U0GDfBKZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0c2Q8PZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_AfSrW2fH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AfSrW2fH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fYIGIy4g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_L32pkHgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MzIc2FTR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_MzIc2FTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_mLJFGtpC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_KWu42cpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KWu42cpT, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KFuuUTlW, 0, m, &cDelay_KFuuUTlW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KWu42cpT, 0, m, &cDelay_KWu42cpT_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rGs4DYf0, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_KFuuUTlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KFuuUTlW, m);
  cMsg_uErMLFZm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_WoefED2j_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_CdmlYOc2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_pZVe9ToI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q9f1SMEX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_cqHivfi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3vbBonrY_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KWu42cpT, 2, m, &cDelay_KWu42cpT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0OUruLu7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_q9f1SMEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_cqHivfi4, 0, m, &hTable_cqHivfi4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mLJFGtpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_pZVe9ToI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_uErMLFZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_cqHivfi4, 0, m, &hTable_cqHivfi4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0OUruLu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KWu42cpT, 0, m, &cDelay_KWu42cpT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3vbBonrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_KFuuUTlW, 2, m, &cDelay_KFuuUTlW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CdmlYOc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rGs4DYf0, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_wFEeObRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cwS8fwUg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_cwS8fwUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_fiHjKz2S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_cLXxqpoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cLXxqpoF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NsIkxHOI, 0, m, &cDelay_NsIkxHOI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cLXxqpoF, 0, m, &cDelay_cLXxqpoF_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_a2uhEWMx, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_NsIkxHOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NsIkxHOI, m);
  cMsg_bsVN35iC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_LHDFO3Kw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_7eVcFNkQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_r2kI2tsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_apniXfi3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_wI3XSRy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nl57AAvl_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cLXxqpoF, 2, m, &cDelay_cLXxqpoF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B0RzmDPT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_apniXfi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_wI3XSRy2, 0, m, &hTable_wI3XSRy2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fiHjKz2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_r2kI2tsC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bsVN35iC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_wI3XSRy2, 0, m, &hTable_wI3XSRy2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_B0RzmDPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cLXxqpoF, 0, m, &cDelay_cLXxqpoF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Nl57AAvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_NsIkxHOI, 2, m, &cDelay_NsIkxHOI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7eVcFNkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_a2uhEWMx, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_mv0BXzJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pmiY9y9Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_pmiY9y9Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Qv6dh7EY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HUH1GOWU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_HUH1GOWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b2HKAIjl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_pmiY9y9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_W4vQVeZD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bZHazzCp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pmiY9y9Y, HV_BINOP_MULTIPLY, 1, m, &cBinop_pmiY9y9Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_b2HKAIjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bZHazzCp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_W4vQVeZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_1foeFlwR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1foeFlwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_JH5g61Ad_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_tOfqHuTn, m);
}

void Heavy_WSTD_FL3NGR::cBinop_JH5g61Ad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xhvIJwxQ, m);
}

void Heavy_WSTD_FL3NGR::cVar_NqthXCXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gZ63QgqG, HV_BINOP_MULTIPLY, 0, m, &cBinop_gZ63QgqG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_lONbZITx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_C79bpKI2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_C79bpKI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PJBOts4A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gZ63QgqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hBO47Y0B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ifwxjeyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gZ63QgqG, HV_BINOP_MULTIPLY, 1, m, &cBinop_gZ63QgqG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_PJBOts4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ifwxjeyS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hBO47Y0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0kzcDhPi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0kzcDhPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_WlF3gQsA_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_OkF13VSG, m);
}

void Heavy_WSTD_FL3NGR::cBinop_WlF3gQsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tePQbmFk, m);
}

void Heavy_WSTD_FL3NGR::cMsg_fYIGIy4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LNmnrb2u, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_eKcXPQqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_XuE5RY59_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8pHOOVnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VNJhyfxw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_D2lrGKKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_eKcXPQqc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QEuMQlKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_h1F0qrDO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_h1F0qrDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oyjVqVrk, HV_BINOP_MULTIPLY, 1, m, &cBinop_oyjVqVrk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VNJhyfxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_QEuMQlKy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oyjVqVrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dmVqua56_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XuE5RY59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oyjVqVrk, HV_BINOP_MULTIPLY, 0, m, &cBinop_oyjVqVrk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_dmVqua56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t6xQ8OhI, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_m2V0RiQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_9zk8q1z3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9zk8q1z3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8pHOOVnO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D2lrGKKy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_CsyYtTaS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_R2Fiifbe, 0, m, &cSlice_R2Fiifbe_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5LTbWDyw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_R2Fiifbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5DdeeyAN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5DdeeyAN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_PQ3xnQkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5DdeeyAN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_5DdeeyAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_imHiq4Kg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_5LTbWDyw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zU4U52KV, 0, m, &cSlice_zU4U52KV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_t2mRuC8I_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_zU4U52KV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_N2swE8Gw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_N2swE8Gw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_aJvK3iXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_N2swE8Gw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_N2swE8Gw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ROvoogi2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_t2mRuC8I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jllfrVBC, 0, m, &cSlice_jllfrVBC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jR6WPNYj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_jllfrVBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9r5vcxJR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9r5vcxJR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_xQ4tuQUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9r5vcxJR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_9r5vcxJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XduQZLfi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_jR6WPNYj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ostl3bWN, 0, m, &cSlice_ostl3bWN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ostl3bWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_n4lfOawq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_n4lfOawq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_KWzA91a1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n4lfOawq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_n4lfOawq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0RzQP4ZS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_rdxKkPv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kWhSGRWf, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_8c8SK7zE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0CLbxp3F, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_W2DMYQm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Je0b3zVQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Je0b3zVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_ikm8GvEK, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_wgc4p0G3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JRhiFZIN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_JRhiFZIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9sGeshrV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_g4aWACnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y4FA5liU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_9sq4wc7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_aATy9pq3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Z1q59qWj, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9sGeshrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dkeoo8Ls, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Y4FA5liU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9sq4wc7H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aATy9pq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_avPNOStI, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ZBmxyuc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VUg93tuM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_VUg93tuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_TXcW7ylD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_FxCraoi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_chr1KKia_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_djHYhYt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_G7cM5A7Z_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dYpoNgU0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TXcW7ylD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_huT75Ljk, m);
}

void Heavy_WSTD_FL3NGR::cMsg_chr1KKia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_djHYhYt4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G7cM5A7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_PntNxsAA, m);
}

void Heavy_WSTD_FL3NGR::cBinop_GQU5KCzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Fc4CfVjK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Fc4CfVjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_q7Zp4sED_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_CTzfnehj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BDAY1W2E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_MnkSQwkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ublLKjZl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_q7Zp4sED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_juqmVOl1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_juqmVOl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zIMjB3wG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FLiv6tpV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FLiv6tpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4m5Otne9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_zIMjB3wG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_FjzksVVG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FjzksVVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tsW3s1Y7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4m5Otne9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2e1EJfi3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2e1EJfi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mXiuqaVr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tsW3s1Y7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_CTzfnehj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mXiuqaVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_MnkSQwkr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Rp0KqFvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_cDjh2Nwv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cDjh2Nwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f585GM53_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_PEmWZxFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_564XeT6Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_564XeT6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZCq9tj85_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_cSSjkhUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cSSjkhUh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nyizN9gi, 0, m, &cDelay_nyizN9gi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cSSjkhUh, 0, m, &cDelay_cSSjkhUh_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_TIIRkByq, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_nyizN9gi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nyizN9gi, m);
  cMsg_57maxcut_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_LrNYxTK2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_c5a3qP86_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_lpEPClGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u2gE2G8w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_73gc2tIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YO2lhTNH_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cSSjkhUh, 2, m, &cDelay_cSSjkhUh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_10Pwic7W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_u2gE2G8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_73gc2tIx, 0, m, &hTable_73gc2tIx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZCq9tj85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_lpEPClGn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_57maxcut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_73gc2tIx, 0, m, &hTable_73gc2tIx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_10Pwic7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cSSjkhUh, 0, m, &cDelay_cSSjkhUh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YO2lhTNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_nyizN9gi, 2, m, &cDelay_nyizN9gi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_c5a3qP86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_TIIRkByq, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_TXrWICpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eDjFZXl8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_eDjFZXl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_OlQ8llm4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_pJlm5a33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pJlm5a33, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9KsdumbY, 0, m, &cDelay_9KsdumbY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pJlm5a33, 0, m, &cDelay_pJlm5a33_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Q4R20UFV, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_9KsdumbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9KsdumbY, m);
  cMsg_YdPFgr0Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_dxC1iO9n_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_gl0KjCzr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_96yOfEzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7xShsAUk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_C6pUYsQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O66QCUFt_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pJlm5a33, 2, m, &cDelay_pJlm5a33_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yAG32We0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7xShsAUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_C6pUYsQg, 0, m, &hTable_C6pUYsQg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OlQ8llm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_96yOfEzT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YdPFgr0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_C6pUYsQg, 0, m, &hTable_C6pUYsQg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yAG32We0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pJlm5a33, 0, m, &cDelay_pJlm5a33_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_O66QCUFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_9KsdumbY, 2, m, &cDelay_9KsdumbY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_gl0KjCzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Q4R20UFV, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_hAzfD8cj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H2aP5rWD, HV_BINOP_MULTIPLY, 0, m, &cBinop_H2aP5rWD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_yuLLJQUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1wTqksRc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_1wTqksRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bUI9hC6W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_H2aP5rWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_TFJjIZKB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mh0TbBKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H2aP5rWD, HV_BINOP_MULTIPLY, 1, m, &cBinop_H2aP5rWD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bUI9hC6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mh0TbBKk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TFJjIZKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_q4kjLG1y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_q4kjLG1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_MIgTBljh_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dFzaKFfU, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MIgTBljh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pL7MCPXd, m);
}

void Heavy_WSTD_FL3NGR::cVar_kaXTdCr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nFg0iL7B, HV_BINOP_MULTIPLY, 0, m, &cBinop_nFg0iL7B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_J91FJw5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_puwjH8uZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_puwjH8uZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xeVZlsym_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nFg0iL7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_fzKdMKZB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VBttMs08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nFg0iL7B, HV_BINOP_MULTIPLY, 1, m, &cBinop_nFg0iL7B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xeVZlsym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VBttMs08_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fzKdMKZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_94VufaTr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_94VufaTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FUxdE3TC_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eKOp31Wt, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FUxdE3TC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Gr8c2p3F, m);
}

void Heavy_WSTD_FL3NGR::cMsg_f585GM53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gsjbwBhE, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_37pQJo1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_mGKFAxN8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xpmlRKsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_37pQJo1y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9Qe4puzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QfFHkMHV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wfGSXvjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_oAVVy50C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oAVVy50C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qY8hUUKX, HV_BINOP_MULTIPLY, 1, m, &cBinop_qY8hUUKX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QfFHkMHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_wfGSXvjp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qY8hUUKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eUkbri91_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_mGKFAxN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qY8hUUKX, HV_BINOP_MULTIPLY, 0, m, &cBinop_qY8hUUKX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_eUkbri91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CgKIF7uL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_X01KMbIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_9jhVimfo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9jhVimfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Qe4puzr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xpmlRKsk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_YuKGJ0bO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nTBKb6pr, 0, m, &cSlice_nTBKb6pr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zMMjqeXf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_nTBKb6pr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hC4wEU2u_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hC4wEU2u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_h4HfeEzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hC4wEU2u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_hC4wEU2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_s4HU8KkC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_zMMjqeXf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4OFwtWdQ, 0, m, &cSlice_4OFwtWdQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ERst2eQ4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_4OFwtWdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MtCCmFuW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MtCCmFuW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_lQzffpgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MtCCmFuW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_MtCCmFuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_79b45fo0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_ERst2eQ4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rQ2crSe6, 0, m, &cSlice_rQ2crSe6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_E6eTH3es_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_rQ2crSe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LloqpmeK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LloqpmeK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ey4puTSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LloqpmeK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_LloqpmeK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2DFzVxNZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_E6eTH3es_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FO7kg8CV, 0, m, &cSlice_FO7kg8CV_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_FO7kg8CV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4MQU9ttb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4MQU9ttb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_QJfR8x7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4MQU9ttb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_4MQU9ttb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7RT6oJes_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_BDAY1W2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CF2E3EVA, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ublLKjZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MjTQtPtN, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_4cSiLAq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_BmGuQwFz_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CQjSSbZZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_K9iaHmX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_BmGuQwFz_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CQjSSbZZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_cBv69XXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_BmGuQwFz_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CQjSSbZZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_EYASaWU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_BmGuQwFz_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CQjSSbZZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_SC2hxDvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_BmGuQwFz_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CQjSSbZZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hEYA38Xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_zBRiBy6C, 0, m, &cVar_zBRiBy6C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zTTjOHTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ZovOz8sO, 0, m, &cVar_ZovOz8sO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NSAvrq6e, 0, m, &cVar_NSAvrq6e_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9yGnwHVx, 0, m, &cVar_9yGnwHVx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jWCPQYVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_V3g7m9C0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_M9cnVves_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_V3g7m9C0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ZgdxoIv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_V3g7m9C0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xARcb0f7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_V3g7m9C0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_pHCNHALe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NmVZGldt, 0, m, &cVar_NmVZGldt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XTqbjCUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ltbeW5jj, 0, m, &cVar_ltbeW5jj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6HAy295Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rNMzVf69, 0, m, &cVar_rNMzVf69_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NX7K5NUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CsyYtTaS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ZmuXOtr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CsyYtTaS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_F85cPO2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CsyYtTaS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_JkKCg4xc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CsyYtTaS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_jrOdSOiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BL5uwWjS, 0, m, &cVar_BL5uwWjS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yJJ3Yyxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nOYdbUCZ, 0, m, &cVar_nOYdbUCZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_l2RyHDm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1ZyuPeHx, 0, m, &cVar_1ZyuPeHx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ftrN8Ix2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_YuKGJ0bO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_nQ8y8TnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_YuKGJ0bO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hGbG8uvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_YuKGJ0bO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_MdFBlMiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_YuKGJ0bO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_Cptgidrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s6r7mBYu, 0, m, &cVar_s6r7mBYu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1bWRvwXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ELSkdrSN, 0, m, &cVar_ELSkdrSN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SZMoRY5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IF0rM8OE, 0, m, &cVar_IF0rM8OE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Ea4E8Ldy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZovOz8sO, 0, m, &cVar_ZovOz8sO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_jtMD63gY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NSAvrq6e, 0, m, &cVar_NSAvrq6e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_yM3gt0yO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9yGnwHVx, 0, m, &cVar_9yGnwHVx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_u5YJz6xu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AAyuPqol, 0, m, &cVar_AAyuPqol_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_NrlQgeQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AinG2KlV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EuHektHM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LReNmlMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3XBcF2t2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FOvV3nOr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mILj4jpO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_TQxiemwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5lzHhVfl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G2c3quxA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wC1LMk8x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bGdmIuRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x538HeES_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u3rSGnNL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fFzdWynN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Uv2lMkPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OQ1CnFsP_sendMessage(_c, 0, m);
  cMsg_LwFt1292_sendMessage(_c, 0, m);
  cMsg_NGaHfCTq_sendMessage(_c, 0, m);
  cMsg_rxaFVeVQ_sendMessage(_c, 0, m);
  cMsg_3R6IlNN3_sendMessage(_c, 0, m);
  cMsg_mnUcgyHZ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fX2wzFe3, 0, m, &cVar_fX2wzFe3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AAyuPqol, 0, m, &cVar_AAyuPqol_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9B2nbh3N, 0, m, &cVar_9B2nbh3N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Nf8CrU7B, 0, m, &cVar_Nf8CrU7B_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EtsbaGhU, 0, m, &cVar_EtsbaGhU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0N608zZH, 0, m, &cVar_0N608zZH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1YBpiBPh, 0, m, &cVar_1YBpiBPh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fCMdw0oC, 0, m, &cVar_fCMdw0oC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_e5hbszRZ, 0, m, &cVar_e5hbszRZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NIUfiMLd, 0, m, &cVar_NIUfiMLd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HwyRZcoy, 0, m, &cVar_HwyRZcoy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bXKOWz8u, 0, m, &cVar_bXKOWz8u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xdg9NDo5, 0, m, &cVar_xdg9NDo5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vw1PIAs3, 0, m, &cVar_vw1PIAs3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XRFS5uzn, 0, m, &cVar_XRFS5uzn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vYbOPsDL, 0, m, &cVar_vYbOPsDL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IiWsqxSy, 0, m, &cVar_IiWsqxSy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IcbZFiAf, 0, m, &cVar_IcbZFiAf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vN1n7vP3, 0, m, &cVar_vN1n7vP3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_04Bgmd2S, 0, m, &cVar_04Bgmd2S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_doPLeQVQ, 0, m, &cVar_doPLeQVQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NyhFtEfy, 0, m, &cVar_NyhFtEfy_sendMessage);
  cMsg_QFuJccmS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lO1WOAYn, 0, m, &cVar_lO1WOAYn_sendMessage);
  cMsg_SUSlXnbe_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tGHAxRcf, 0, m, &cVar_tGHAxRcf_sendMessage);
  cMsg_Qv6dh7EY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mv0BXzJf, 0, m, &cVar_mv0BXzJf_sendMessage);
  cMsg_lONbZITx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NqthXCXl, 0, m, &cVar_NqthXCXl_sendMessage);
  cMsg_yuLLJQUB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hAzfD8cj, 0, m, &cVar_hAzfD8cj_sendMessage);
  cMsg_J91FJw5J_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kaXTdCr5, 0, m, &cVar_kaXTdCr5_sendMessage);
  cMsg_b3RkPtOt_sendMessage(_c, 0, m);
  cMsg_6W3tskl1_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KRBC8oES, 0, m, &cVar_KRBC8oES_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_K99ZNI8u, 0, m, &cVar_K99ZNI8u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZFurfJWd, 0, m, &cVar_ZFurfJWd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OB423o0A, 0, m, &cVar_OB423o0A_sendMessage);
  cMsg_L32pkHgn_sendMessage(_c, 0, m);
  cMsg_wFEeObRs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PQ3xnQkG, 0, m, &cVar_PQ3xnQkG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aJvK3iXP, 0, m, &cVar_aJvK3iXP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xQ4tuQUm, 0, m, &cVar_xQ4tuQUm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KWzA91a1, 0, m, &cVar_KWzA91a1_sendMessage);
  cMsg_PEmWZxFb_sendMessage(_c, 0, m);
  cMsg_TXrWICpy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_h4HfeEzV, 0, m, &cVar_h4HfeEzV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lQzffpgp, 0, m, &cVar_lQzffpgp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ey4puTSB, 0, m, &cVar_ey4puTSB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QJfR8x7R, 0, m, &cVar_QJfR8x7R_sendMessage);
  cMsg_zTTjOHTZ_sendMessage(_c, 0, m);
  cMsg_hEYA38Xd_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4zxrmQ4X, 0, m, &cVar_4zxrmQ4X_sendMessage);
  cMsg_yGL0j7qD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_eHALaulb, 0, m, &cVar_eHALaulb_sendMessage);
  cMsg_WiXhjYQM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Yk0moOtE, 0, m, &cVar_Yk0moOtE_sendMessage);
  cMsg_FpaM0vJH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_XcxK5Snh, 0, m, &cVar_XcxK5Snh_sendMessage);
  cMsg_yNVQYjgN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_g4aWACnE, 0, m, &cVar_g4aWACnE_sendMessage);
  cMsg_wgc4p0G3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_FxCraoi8, 0, m, &cVar_FxCraoi8_sendMessage);
  cMsg_ZBmxyuc2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_MCkdcjpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eINqciv1, HV_BINOP_MULTIPLY, 0, m, &cBinop_eINqciv1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Q6UhjniK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fV5MeNbv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_324T7gpU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iiiTNooa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_H4LlYKyD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_dc4gHky1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_c5ztenVF_sendMessage);
  cMsg_UAMi22v3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_doAF7aVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZuVDMuPN, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZuVDMuPN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_k933W5Jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ZURJipps_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_47ETSCbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Us4gGU7, HV_BINOP_MULTIPLY, 1, m, &cBinop_8Us4gGU7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5db9oCg3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0oWyd9wh_sendMessage);
  cMsg_8A29q1CP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_DzmCCkkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dEdxLiK6, HV_BINOP_MULTIPLY, 0, m, &cBinop_dEdxLiK6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_YllDyx8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7MLhsur2_sendMessage(_c, 0, m);
  cMsg_1fXlFTew_sendMessage(_c, 0, m);
  cMsg_7cov59um_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_MPoAwvT5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Dka84Ncr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ShUkWpFd_sendMessage);
  cMsg_bP6zoYSO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_uviM10uI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EtsbaGhU, 0, m, &cVar_EtsbaGhU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_36orl0wL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iV3CR9z7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YeWTZJbT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0zUbxgdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YRqAefZJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TkXT1z9P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ch2jjEp5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_tDNZv7jQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BmL692p6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R7anBLg9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q9Z6i29g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_W0a3rMZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vi5ggtu8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K0D1hVl5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fpYlnHAt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_agz6xWPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_beZJgt7B, HV_BINOP_MULTIPLY, 0, m, &cBinop_beZJgt7B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_WMZ3xPHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ly6iHunE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_otYM9Xb3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7EQT1gZs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_6AuL5CtR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_S11JsLO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RSw1Lita_sendMessage);
  cMsg_5PEdlHuA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_VcVCdSPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3etkvjpq, HV_BINOP_MULTIPLY, 0, m, &cBinop_3etkvjpq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_pkmeFHlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_E6nVhmPY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_O4F3OFh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_afSFSWoJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_afSFSWoJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_eK2NugB7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_c8Lyz7NI_sendMessage);
  cMsg_1LWbuXcv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_F02qcMb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7903jqqL, HV_BINOP_MULTIPLY, 0, m, &cBinop_7903jqqL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_3k41hT8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K3sOOJoN_sendMessage(_c, 0, m);
  cMsg_QcqdtN0l_sendMessage(_c, 0, m);
  cMsg_9EyZEz4L_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_sjEOeHh6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_OhJQEDQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_19dcUCpQ_sendMessage);
  cMsg_2QzXmxDC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_a9f2qUgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zBRiBy6C, 0, m, &cVar_zBRiBy6C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_cjl0QoTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_pHCNHALe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_h3Mn8KzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_XTqbjCUh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_zS0FWYsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GODBne8o, 0, m, &cVar_GODBne8o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_5VKZ9HiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_6HAy295Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_CV7Esst0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_jrOdSOiz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_BPT06rxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_yJJ3Yyxv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_8Nm0XwAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_afZS3Lig, 0, m, &cVar_afZS3Lig_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_WaAkJdEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_l2RyHDm3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_b04nk1dS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Cptgidrm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_3aVkVCf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_1bWRvwXo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_f7fpqKzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CytW3TUX, 0, m, &cVar_CytW3TUX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_uCuddKry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_SZMoRY5e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_dQJeokLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_nYrMwLNu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qMSi57oq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_GCyAY35p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bMhBSUXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rR7UyAGJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XmwVWaaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_96f3GLF3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XduQZLfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_WCzcqBow_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ROvoogi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_m2V0RiQZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0RzQP4ZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_KVB2FfdD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_imHiq4Kg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0c2Q8PZa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_2DFzVxNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_W2DMYQm8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_79b45fo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_X01KMbIQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_7RT6oJes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_GQU5KCzj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_s4HU8KkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Rp0KqFvp_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_XLdJbJq6, VOf(Bf0));
    __hv_line_f(&sLine_FB13jTQf, VOf(Bf1));
    __hv_line_f(&sLine_x6vYuA93, VOf(Bf2));
    __hv_line_f(&sLine_ZS3MVA2n, VOf(Bf3));
    __hv_line_f(&sLine_z83uZGVH, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_FsIvn6xM, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_bJVmHlgL, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_W2KQonv4, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_t4oBMgmz, VOf(Bf1));
    __hv_line_f(&sLine_gNOLj3oU, VOf(Bf0));
    __hv_line_f(&sLine_iQZSyOuE, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_BEvKqZFE, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_jQqz1FoQ, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_jdhDHsGm, VOf(Bf5));
    __hv_line_f(&sLine_avsmylyo, VOf(Bf1));
    __hv_line_f(&sLine_QPHzUIM0, VOf(Bf2));
    __hv_line_f(&sLine_3jAYHYcw, VOf(Bf4));
    __hv_line_f(&sLine_3X6jcika, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_HhgoH7n5, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_z2X0AFSh, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_RU5HxvtD, VOf(Bf6));
    __hv_line_f(&sLine_epRe6M1g, VOf(Bf2));
    __hv_line_f(&sLine_ku9hKyVk, VOf(Bf1));
    __hv_line_f(&sLine_Krauvyn8, VOf(Bf5));
    __hv_line_f(&sLine_L7ubCZ9f, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_r16WKEZr, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_lrWlTZAZ, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_KlqGuDxv, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_WH9VXLdd, VOf(Bf2));
    __hv_line_f(&sLine_p37h2B2U, VOf(Bf6));
    __hv_line_f(&sLine_GgjSUe53, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_bOO2If94, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_wOo0RVca, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_yPfTn93o, VOf(Bf8));
    __hv_line_f(&sLine_LP2II8li, VOf(Bf2));
    __hv_line_f(&sLine_Dsif3AWG, VOf(Bf1));
    __hv_line_f(&sLine_5PnBOGPw, VOf(Bf7));
    __hv_line_f(&sLine_SEltjmPJ, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_Mh0Kibmy, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_CjjxqviT, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_FLVS4wT6, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_yNFmI11y, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_hDjhdwA0, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_MrVZNbLr, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_i9PAF8P1, VOf(Bf8));
    __hv_rpole_f(&sRPole_OoI6H05W, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_6uKl5lal, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_TQBWOuWr, VOf(Bf10));
    __hv_rpole_f(&sRPole_iJYBvFZB, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_YbPb05yc, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_gQAS2LGX, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_dVwd303a, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_N0tHSzAl, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_o1mcaQfo, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_DsDmYT9s, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_GRA5D9rs, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_jiwDJ6gz, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_6Vu96kw9, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_1adF9Pbh, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_XmNOquZT, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_FHUaXP6F, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_DDAlTIcC, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_8AuUDiTO, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_1CQQ9hQW, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_d1UnsjEj, VIf(Bf3));
    __hv_varwrite_f(&sVarf_DOz31INJ, VIf(Bf11));
    __hv_line_f(&sLine_0CLbxp3F, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_ZnIrTMyZ, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_LNmnrb2u, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_tOfqHuTn, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_xhvIJwxQ, VOf(Bf10));
    __hv_rpole_f(&sRPole_W9NLTj5n, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_OkF13VSG, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_tePQbmFk, VOf(Bf5));
    __hv_rpole_f(&sRPole_ZV3sIsj7, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_IdFu6vGX, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_bW0UjTKk, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_FKRUKgsg, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_1sqM5xBU, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_EefyVeF7, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_DdMDIDWv, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_kWhSGRWf, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_mPPRRI2Q, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_M2BAPQa1, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_pTrTk4g9, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_rGFgVMIZ, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Cri4WlIp, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_GmY7G2P8, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_t6xQ8OhI, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_rGs4DYf0, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_a2uhEWMx, VIf(Bf0));
    __hv_varwrite_f(&sVarf_iB0caOG3, VIf(Bf8));
    __hv_line_f(&sLine_MjTQtPtN, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_ikm8GvEK, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_gsjbwBhE, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_dFzaKFfU, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_pL7MCPXd, VOf(Bf5));
    __hv_rpole_f(&sRPole_btVZsamO, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_eKOp31Wt, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_Gr8c2p3F, VOf(Bf6));
    __hv_rpole_f(&sRPole_8vDgbBrS, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_ZVrT6OBS, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_dkeoo8Ls, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_avPNOStI, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_Z1q59qWj, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_eXfy0Gj5, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_4qL0FFAY, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_CF2E3EVA, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_CFLKa9XF, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_huT75Ljk, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_PntNxsAA, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_dYpoNgU0, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_GQs7hpBx, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_WwRaf1ci, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_CgKIF7uL, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_TIIRkByq, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_Q4R20UFV, VIf(Bf4));
    __hv_varwrite_f(&sVarf_OGnSk1nZ, VIf(Bf10));
    __hv_varwrite_f(&sVarf_RuTb7OET, VIf(Bf2));
    __hv_varwrite_f(&sVarf_zG4amzRO, VIf(Bf9));
    __hv_varwrite_f(&sVarf_nkoo871k, VIf(Bf11));
    __hv_varread_f(&sVarf_RuTb7OET, VOf(Bf11));
    __hv_varread_f(&sVarf_zG4amzRO, VOf(Bf9));
    __hv_varread_f(&sVarf_nkoo871k, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_DOz31INJ, VOf(Bf2));
    __hv_varread_f(&sVarf_iB0caOG3, VOf(Bf11));
    __hv_varread_f(&sVarf_OGnSk1nZ, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
